==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Vos paramètres ont été mis à jour.",
"Activity" => "Activité",
"A file or folder has been <strong>shared</strong>" => "Un fichier ou un répertoire a été <strong>partagé</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Un nouveau fichier ou répertoire a été <strong>créé</strong> dans un dossier partagé",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Un fichier ou un répertoire a été <strong>modifié</strong> dans un dossier partagé",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Un fichier ou un répertoire a été <strong>supprimé</strong> dans un dossier partagé",
"You created %1\$s" => "Vous avez créé %1\$s",
"%2\$s created %1\$s" => "%2\$s a créé %1\$s",
"You changed %1\$s" => "Vous avez changé %1\$s",
"%2\$s changed %1\$s" => "%2\$s a changé %1\$s",
"You deleted %1\$s" => "Vous avez supprimé %1\$s",
"%2\$s deleted %1\$s" => "%2\$s a supprimé %1\$s",
"You shared %1\$s with %2\$s" => "Vous avez partagé %1\$s avec %2\$s",
"You shared %1\$s with group %2\$s" => "Vous avez partagé %1\$s avec le groupe %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s a partagé %1\$s avec vous",
"You shared %1\$s via link" => "Vous avez partagé %1\$s via lien public",
"Activity notification" => "Notification d'activité",
"All Activities" => "Toute l'activité",
"Activities by you" => "Votre activité",
"Activities by others" => "L'activité des autres",
"Shares" => "Partages",
"Files" => "Fichiers",
"%s and %s" => "%s et %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s et <strong class=\"tooltip\" title=\"%s\">%n autre</strong>","%s et <strong class=\"tooltip\" title=\"%s\">%n autres</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s et %n autre","%s et %n autres"),
"Hello %s," => "Bonjour %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Vous recevez ce courriel car pendant l'heure précédente l'activité suivante a eu lieu sur %s",
"You are receiving this email because in the last day the following things happened at %s" => "Vous recevez ce courriel car hier l'activité suivante a eu lieu sur %s",
"You are receiving this email because in the last week the following things happened at %s" => "Vous recevez ce courriel car la semaine dernière l'activité suivante a eu lieu sur %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Vous verrez ici une liste d'événements lorsque vous commencerez à utiliser votre %s.",
"No more events to load" => "Plus aucun événement à charger",
"Enable RSS feed" => "Activer les flux RSS",
"Notifications" => "Notifications",
"Mail" => "Mail",
"Stream" => "Flux",
"You need to set up your email address before you can receive notification emails." => "Il est nécessaire de configurer une adresse courriel avant de pouvoir recevoir les notifications par courriel.",
"Send emails:" => "Envoyer des courriels :",
"Hourly" => "Toutes les heures",
"Daily" => "Quotidien",
"Weekly" => "Hebdomadaire",
"Activity feed" => "Flux d'activité",
"Personal activity feed for %s" => "Flux d'activité personnel de %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Vos paramètres ont été mis à jour.",
"Activity" => "Activité",
"A file or folder has been <strong>shared</strong>" => "Un fichier ou un répertoire a été <strong>partagé</strong>",
"A new file or folder has been <strong>created</strong>" => "Un nouveau fichier ou un nouveau répertoire a été <strong>créé</strong>",
"A file or folder has been <strong>changed</strong>" => "Un fichier ou un répertoire à été <strong>modifié</strong>",
"A file or folder has been <strong>deleted</strong>" => "Un fichier ou un répertoire à été <strong>supprimé</strong>",
"You created %1\$s" => "Vous avez créé %1\$s",
"%2\$s created %1\$s" => "%2\$s a créé %1\$s",
"You changed %1\$s" => "Vous avez changé %1\$s",
"%2\$s changed %1\$s" => "%2\$s a changé %1\$s",
"You deleted %1\$s" => "Vous avez supprimé %1\$s",
"%2\$s deleted %1\$s" => "%2\$s a supprimé %1\$s",
"You shared %1\$s with %2\$s" => "Vous avez partagé %1\$s avec %2\$s",
"You shared %1\$s with group %2\$s" => "Vous avez partagé %1\$s avec le groupe %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s a partagé %1\$s avec vous",
"You shared %1\$s via link" => "Vous avez partagé %1\$s via lien public",
"Activity notification" => "Notification d'activité",
"All Activities" => "Toute l'activité",
"Activities by you" => "Votre activité",
"Activities by others" => "L'activité des autres",
"Shares" => "Partages",
"Files" => "Fichiers",
"%s and %s" => "%s et %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s et <strong class=\"tooltip\" title=\"%s\">%n autre</strong>","%s et <strong class=\"tooltip\" title=\"%s\">%n autres</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s et %n autre","%s et %n autres"),
"Hello %s," => "Bonjour %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Vous recevez ce courriel car pendant l'heure précédente l'activité suivante a eu lieu sur %s",
"You are receiving this email because in the last day the following things happened at %s" => "Vous recevez ce courriel car hier l'activité suivante a eu lieu sur %s",
"You are receiving this email because in the last week the following things happened at %s" => "Vous recevez ce courriel car la semaine dernière l'activité suivante a eu lieu sur %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Vous verrez ici une liste d'événements lorsque vous commencerez à utiliser votre %s.",
"No more events to load" => "Plus aucun événement à charger",
"Enable RSS feed" => "Activer les flux RSS",
"Notifications" => "Notifications",
"Mail" => "Mail",
"Stream" => "Flux",
"Notify about my own actions" => "M'informer de mes propres actions",
"You need to set up your email address before you can receive notification emails." => "Il est nécessaire de configurer une adresse courriel avant de pouvoir recevoir les notifications par courriel.",
"Send emails:" => "Envoyer des courriels :",
"Hourly" => "Toutes les heures",
"Daily" => "Quotidien",
"Weekly" => "Hebdomadaire",
"Activity feed" => "Flux d'activité",
"Personal activity feed for %s" => "Flux d'activité personnel de %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
